{% extends "admin/base_site.html" %}
{% load i18n admin_static %}
{% load otto_admin_tags %}
{% load static %}

{% block extrastyle %}
    {{ block.super }}
    <link rel="stylesheet" type="text/css" href="{% static 'otto_admin/css/dashboard.css' %}">
{% endblock %}

{% block coltype %}colMS{% endblock %}

{% block bodyclass %}dashboard{% endblock %}

{% block breadcrumbs %}{% endblock %}

{% block content %}
    <div id="content-main">
        {% analytics %}
    </div>
{% endblock %}


{% block sidebar %}
    <div id="content-related">
        <div class="module" id="recent-actions-module">
            <h4 class="italic-title">{% trans 'My Actions' %}</h4>

            {% load log %}
            {% get_admin_log 10 as admin_log for_user user %}
            {% if not admin_log %}
                <p>{% trans 'None available' %}</p>
            {% else %}
                <ul class="actionlist">
                    {% for entry in admin_log %}
                        <li class="{% if entry.is_addition %}addlink{% endif %}{% if entry.is_change %}changelink{% endif %}{% if entry.is_deletion %}text-error{% endif %}">

                            <i class="{% if entry.is_addition %}icon-plus{% endif %}{% if entry.is_change %}icon-pencil{% endif %}{% if entry.is_deletion %}icon-trash{% endif %} icon-alpha5"></i>

                            {% spaceless %}
                                {% if entry.is_addition %}{% trans 'added'|capfirst %}{% endif %}
                                {% if entry.is_change %}{% trans 'changed'|capfirst %}{% endif %}
                                {% if entry.is_deletion %}{% trans 'deleted'|capfirst %}{% endif %}

                                {% if entry.content_type %}
                                    <span class="mini quiet">{% filter capfirst %}
                                        {% trans entry.content_type.name %}{% endfilter %}</span>
                                {% else %}
                                    <span class="mini quiet">{% trans 'Unknown content' %}</span>
                                {% endif %}
                            {% endspaceless %}&nbsp;

                            {% if entry.is_deletion or not entry.get_admin_url %}
                                <span class="color-grey">{{ entry.object_repr }}</span>
                            {% else %}
                                <a href="{{ entry.get_admin_url }}">{{ entry.object_repr }}</a>
                            {% endif %}
                        </li>
                    {% endfor %}
                </ul>
            {% endif %}
        </div>
    </div>
{% endblock %}
